@@ -36,6 +36,10 @@ class InvalidPhoneNumber(RequestDataError):
     pass
 
 
+class MissingFields(RequestDataError):
+    pass
+
+
 class TransactionError(RevolutError):
     """An exception that makes a transaction impossible to perform."""
 
@@ -48,3 +52,11 @@ class InsufficientBalance(TransactionError):
 
 class NoPocketFound(TransactionError):
     pass
+
+
+class CurrencyMismatch(ValueError, RevolutError):
+    pass
+
+
+class DestinationNotFound(ValueError, RevolutError):
+    pass
