@@ -1,5 +1,7 @@
 import datetime
 import dateutil.parser
+from decimal import Decimal
+import json
 import jwt
 import sys
 
@@ -42,6 +44,13 @@ class _SetEnv(object):
             )
 
 
+class JSONWithDecimalEncoder(json.JSONEncoder):
+    def default(self, o):
+        if isinstance(o, Decimal):
+            return str(o)
+        return super(JSONWithDecimalEncoder, self).default(o)
+
+
 def get_jwt(prvkey, issuer, client_id):
     """Generates JWT signed with the private key"""
     return jwt.encode(
